@@ -1,5 +1,7 @@
 from logging.config import dictConfig
 
+from tortoise.queryset import Q
+
 from .const import (
     QsParsingError,
     WrongParamsError,
@@ -14,10 +16,11 @@ from .utils import (
     Cases,
     RawSQL,
     SQLizer,
+    Singleton,
     timing,
 )
 
-__version__ = "0.0.4"
+__version__ = "0.0.7"
 
 __all__ = [
     "QsParsingError",
@@ -27,8 +30,10 @@ __all__ = [
     "BaseModel",
     "CursorHandler",
     "Cases",
+    "Q",
     "RawSQL",
     "SQLizer",
+    "Singleton",
     "timing",
 ]
 
